Client
======

.. currentmodule:: hdfs_native

.. autoclass:: Client
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~Client.append
      ~Client.create
      ~Client.delete
      ~Client.get_acl_status
      ~Client.get_content_summary
      ~Client.get_file_info
      ~Client.list_status
      ~Client.mkdirs
      ~Client.modify_acl_entries
      ~Client.read
      ~Client.remove_acl
      ~Client.remove_acl_entries
      ~Client.remove_default_acl
      ~Client.rename
      ~Client.set_acl
      ~Client.set_owner
      ~Client.set_permission
      ~Client.set_replication
      ~Client.set_times

   .. rubric:: Methods Documentation

   .. automethod:: append
   .. automethod:: create
   .. automethod:: delete
   .. automethod:: get_acl_status
   .. automethod:: get_content_summary
   .. automethod:: get_file_info
   .. automethod:: list_status
   .. automethod:: mkdirs
   .. automethod:: modify_acl_entries
   .. automethod:: read
   .. automethod:: remove_acl
   .. automethod:: remove_acl_entries
   .. automethod:: remove_default_acl
   .. automethod:: rename
   .. automethod:: set_acl
   .. automethod:: set_owner
   .. automethod:: set_permission
   .. automethod:: set_replication
   .. automethod:: set_times
